ricecooker\.managers package
============================

Submodules
----------

ricecooker\.managers\.progress module
-------------------------------------

.. automodule:: ricecooker.managers.progress
    :members:
    :undoc-members:
    :show-inheritance:

ricecooker\.managers\.tree module
---------------------------------

.. automodule:: ricecooker.managers.tree
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: ricecooker.managers
    :members:
    :undoc-members:
    :show-inheritance:
